==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es-ES" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Curva en malla...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Curva en malla</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Crear malla de forma ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Teselar forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Crear sección desde malla y plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Sección</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Recortar malla con un plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Ajusta una malla con un plano</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Crear</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Cerrar alambre</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Limpiar</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Cancelar</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Malla equivocada seleccionada</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>No fue elegido ningún punto</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Curva en malla</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Alambre</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Ajustar la tolerancia a los vértices</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Umbral de división</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Aproximación por Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerancia de malla</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuidad</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Grado máximo de la curva</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Comenzar</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Teselado</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formas</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opciones de mallado</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Estándar</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Definir segmentos por colores de cara</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplicar colores de cara a la malla</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Desviación angular:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Desviación relativa de superficie</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longitud máxima de arista:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Precisión:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Muy grueso</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grueso</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moderar</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Muy fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Definido por el usuario</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Graduación del tamaño de malla:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elementos por arista:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementos por radio de curvatura:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimizar la superficie</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementos de segundo orden</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Predominio de cuadriláteros</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Opciones</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Superficie de desviación:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Longitud máx. de la arista:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Seleccione primero una forma para el mallado.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>'%1' No es un documento.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Seleccionar plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Por favor seleccione el plano de corte de la malla.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Seleccionar plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Por favor seleccione el plano de corte de la malla.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>MeshPart</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_es-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es-ES" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Curva en malla...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Curva en malla</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Crear malla de forma ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Teselar forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Crear sección desde malla y plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Sección</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>Malla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Recortar malla con un plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Ajusta una malla con un plano</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Crear</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Cerrar alambre</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Limpiar</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Cancelar</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Malla equivocada seleccionada</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>No fue elegido ningún punto</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Curva en malla</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Alambre</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Ajustar la tolerancia a los vértices</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Umbral de división</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Aproximación por Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerancia de malla</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuidad</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Grado máximo de la curva</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Inicio</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Teselado</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formas</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opciones de mallado</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Estándar</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Definir segmentos por colores de cara</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplicar colores de cara a la malla</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Desviación angular:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Desviación relativa de superficie</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longitud máxima de arista:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Precisión:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Muy grueso</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grueso</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moderar</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Muy fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Definido por el usuario</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Graduación del tamaño de malla:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elementos por arista:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementos por radio de curvatura:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimizar la superficie</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementos de segundo orden</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Predominio de cuadriláteros</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Opciones</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Superficie de desviación:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Longitud máx. de la arista:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Seleccione primero una forma para el mallado.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>'%1' No es un documento.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Seleccionar plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Por favor seleccione el plano de corte de la malla.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Seleccionar plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Por favor seleccione el plano de corte de la malla.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Corte por plano</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Seleccione el lado que desea mantener.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Interior</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Exterior</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Dividir</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>MeshPart</translation>
    </message>
  </context>
</TS>
